@@ -41,6 +41,12 @@ void InfiniteMerkuroCalendarViewModel::setup()
         addWeekDates(true, firstDay);
         break;
     }
+    case WorkWeekScale: {
+        QDate firstDay = today.addDays(1 - today.dayOfWeek());
+        firstDay = firstDay.addDays(-m_datesToAdd / 2 * 7);
+        addWorkWeekDates(true, firstDay);
+        break;
+    }
     case MonthScale: {
         QDate firstDay(today.year(), today.month(), 1);
         firstDay = firstDay.addMonths(-m_datesToAdd / 2);
@@ -146,6 +152,8 @@ int InfiniteMerkuroCalendarViewModel::moveToDate(const QDate &selectedDate, cons
         role = InfiniteMerkuroCalendarViewModel::FirstDayOfMonthRole;
         break;
     }
+    // WorkWeekScale behaves like WeekScale for navigation
+    case WorkWeekScale:
     case WeekScale: {
         const int daysTo = currentDate.daysTo(selectedDate) / 7;
         newIndex = currentIndex + daysTo;
@@ -188,6 +196,8 @@ int InfiniteMerkuroCalendarViewModel::moveToDate(const QDate &selectedDate, cons
         case MonthScale:
             newIndex += selectedDate.month() - firstItemDate.month() + (12 * (selectedDate.year() - firstItemDate.year()));
             break;
+        // WorkWeekScale behaves like WeekScale for navigation
+        case WorkWeekScale:
         case WeekScale:
             newIndex += firstItemDate.daysTo(selectedDate) / 7;
             break;
@@ -207,14 +217,14 @@ int InfiniteMerkuroCalendarViewModel::moveToDate(const QDate &selectedDate, cons
         lastItemDate = data(index(rowCount() - 1, 0), role).toDateTime().date();
     }
 
-    if (m_scale == ThreeDayScale || m_scale == WeekScale) {
+    if (m_scale == ThreeDayScale || m_scale == WeekScale || m_scale == WorkWeekScale) {
         const auto newIndexStartDate = index(newIndex, 0).data(StartDateRole).toDate();
         const auto startDateToSelectedDateDays = newIndexStartDate.daysTo(selectedDate);
         const auto dayDiffFloat = static_cast<float>(startDateToSelectedDateDays);
 
         if (m_scale == ThreeDayScale) {
             newIndex += floor(dayDiffFloat / 3);
-        } else if (m_scale == WeekScale) {
+        } else if (m_scale == WeekScale || m_scale == WorkWeekScale) {
             newIndex += floor(dayDiffFloat / 7);
         }
     }
@@ -234,6 +244,9 @@ void InfiniteMerkuroCalendarViewModel::addDates(const bool atEnd, const QDate st
     case WeekScale:
         addWeekDates(atEnd, startFrom);
         break;
+    case WorkWeekScale:
+        addWorkWeekDates(atEnd, startFrom);
+        break;
     case MonthScale:
         addMonthDates(atEnd, startFrom);
         break;
@@ -253,7 +266,16 @@ void InfiniteMerkuroCalendarViewModel::addDayDates(const bool atEnd, const QDate
     beginInsertRows(QModelIndex(), newRow, newRow + m_datesToAdd - 1);
 
     for (int i = 0; i < m_datesToAdd; i++) {
-        QDate startDate = startFrom.isValid() && i == 0 ? startFrom : atEnd ? m_startDates[rowCount() - 1].addDays(amount) : m_startDates[0].addDays(-amount);
+        QDate startDate;
+        if (startFrom.isValid() && i == 0) {
+            startDate = startFrom;
+        } else {
+            if (atEnd) {
+                startDate = m_startDates[rowCount() - 1].addDays(amount);
+            } else {
+                startDate = m_startDates[0].addDays(-amount);
+            }
+        }
 
         if (atEnd) {
             m_startDates.append(startDate);
@@ -272,7 +294,16 @@ void InfiniteMerkuroCalendarViewModel::addWeekDates(const bool atEnd, const QDat
     beginInsertRows(QModelIndex(), newRow, newRow + m_datesToAdd - 1);
 
     for (int i = 0; i < m_datesToAdd; i++) {
-        QDate startDate = startFrom.isValid() && i == 0 ? startFrom : atEnd ? m_startDates[rowCount() - 1].addDays(7) : m_startDates[0].addDays(-7);
+        QDate startDate;
+        if (startFrom.isValid() && i == 0) {
+            startDate = startFrom;
+        } else {
+            if (atEnd) {
+                startDate = m_startDates[rowCount() - 1].addDays(7);
+            } else {
+                startDate = m_startDates[0].addDays(-7);
+            }
+        }
 
         if (startDate.dayOfWeek() != m_locale.firstDayOfWeek()) {
             startDate = startDate.addDays(-startDate.dayOfWeek() + (m_locale.firstDayOfWeek() % 7));
@@ -288,6 +319,38 @@ void InfiniteMerkuroCalendarViewModel::addWeekDates(const bool atEnd, const QDat
     endInsertRows();
 }
 
+void InfiniteMerkuroCalendarViewModel::addWorkWeekDates(const bool atEnd, const QDate &startFrom)
+{
+    const int newRow = atEnd ? rowCount() : 0;
+
+    beginInsertRows(QModelIndex(), newRow, newRow + m_datesToAdd - 1);
+
+    for (int i = 0; i < m_datesToAdd; i++) {
+        QDate startDate;
+        if (startFrom.isValid() && i == 0) {
+            startDate = startFrom;
+        } else {
+            if (atEnd) {
+                startDate = m_startDates[rowCount() - 1].addDays(7);
+            } else {
+                startDate = m_startDates[0].addDays(-7);
+            }
+        }
+
+        if (startDate.dayOfWeek() != Qt::Monday) {
+            startDate = startDate.addDays(1 - startDate.dayOfWeek());
+        }
+
+        if (atEnd) {
+            m_startDates.append(startDate);
+        } else {
+            m_startDates.insert(0, startDate);
+        }
+    }
+
+    endInsertRows();
+}
+
 void InfiniteMerkuroCalendarViewModel::addMonthDates(const bool atEnd, const QDate &startFrom)
 {
     const int newRow = atEnd ? rowCount() : 0;
@@ -295,9 +358,16 @@ void InfiniteMerkuroCalendarViewModel::addMonthDates(const bool atEnd, const QDa
     beginInsertRows(QModelIndex(), newRow, newRow + m_datesToAdd - 1);
 
     for (int i = 0; i < m_datesToAdd; i++) {
-        const QDate firstDay = startFrom.isValid() && i == 0 ? startFrom
-            : atEnd                                          ? m_firstDayOfMonthDates[rowCount() - 1].addMonths(1)
-                                                             : m_firstDayOfMonthDates[0].addMonths(-1);
+        QDate firstDay;
+        if (startFrom.isValid() && i == 0) {
+            firstDay = startFrom;
+        } else {
+            if (atEnd) {
+                firstDay = m_firstDayOfMonthDates[rowCount() - 1].addMonths(1);
+            } else {
+                firstDay = m_firstDayOfMonthDates[0].addMonths(-1);
+            }
+        }
         QDate startDate = firstDay;
 
         startDate = startDate.addDays(-startDate.dayOfWeek() + (m_locale.firstDayOfWeek() % 7));
@@ -324,7 +394,16 @@ void InfiniteMerkuroCalendarViewModel::addYearDates(const bool atEnd, const QDat
     beginInsertRows(QModelIndex(), newRow, newRow + m_datesToAdd - 1);
 
     for (int i = 0; i < m_datesToAdd; i++) {
-        QDate startDate = startFrom.isValid() && i == 0 ? startFrom : atEnd ? m_startDates[rowCount() - 1].addYears(1) : m_startDates[0].addYears(-1);
+        QDate startDate;
+        if (startFrom.isValid() && i == 0) {
+            startDate = startFrom;
+        } else {
+            if (atEnd) {
+                startDate = m_startDates[rowCount() - 1].addYears(1);
+            } else {
+                startDate = m_startDates[0].addYears(-1);
+            }
+        }
 
         if (atEnd) {
             m_startDates.append(startDate);
@@ -343,7 +422,16 @@ void InfiniteMerkuroCalendarViewModel::addDecadeDates(const bool atEnd, const QD
     beginInsertRows(QModelIndex(), newRow, newRow + m_datesToAdd - 1);
 
     for (int i = 0; i < m_datesToAdd; i++) {
-        QDate startDate = startFrom.isValid() && i == 0 ? startFrom : atEnd ? m_startDates[rowCount() - 1].addYears(10) : m_startDates[0].addYears(-10);
+        QDate startDate;
+        if (startFrom.isValid() && i == 0) {
+            startDate = startFrom;
+        } else {
+            if (atEnd) {
+                startDate = m_startDates[rowCount() - 1].addYears(10);
+            } else {
+                startDate = m_startDates[0].addYears(-10);
+            }
+        }
 
         if (atEnd) {
             m_startDates.append(startDate);
