@@ -56,10 +56,10 @@ void MailApplication::setupActions()
     action = new QAction(QIcon::fromTheme(u"document-save-as-symbolic"_s), i18nc("@action", "Save as…"), this);
     mainCollection()->addAction("mail_save_as"_L1, action);
 
-    action = new QAction(QIcon::fromTheme(u"edit-move-symbolic"_s), i18nc("@action", "Move to..."), this);
+    action = new QAction(QIcon::fromTheme(u"edit-move-symbolic"_s), i18nc("@action", "Move to…"), this);
     mainCollection()->addAction("mail_move_to"_L1, action);
 
-    action = new QAction(QIcon::fromTheme(u"edit-copy-symbolic"_s), i18nc("@action", "Copy to..."), this);
+    action = new QAction(QIcon::fromTheme(u"edit-copy-symbolic"_s), i18nc("@action", "Copy to…"), this);
     mainCollection()->addAction("mail_copy_to"_L1, action);
 
     readSettings();
